==> minikube-1.37.0.tar.gz: minikube-1.37.0/site/content/en/docs/_index.md <==
---
title: "Welcome!"
linkTitle: "Documentation"
no_list: true
weight: 1
aliases:
  - /docs/overview
---

minikube quickly sets up a local Kubernetes cluster on macOS, Linux, and Windows. We proudly focus on helping application developers and new Kubernetes users.

![Screenshot](/images/screenshot.png)

🎉 Latest Release: v1.36.0 - May 22, 2025 ([changelog](https://github.com/kubernetes/minikube/blob/master/CHANGELOG.md))

## Highlights

* Supports the latest Kubernetes release (+6 previous minor versions)
* Supports GPUs for AI developement ([nvidia]({{< ref "/docs/tutorials/nvidia.md" >}}), [amd]({{< ref "/docs/tutorials/amd.md" >}}), [apple]({{< ref "/docs/tutorials/ai-playground.md" >}}))
* Cross-platform (Linux, macOS, Windows)
* Deploy as a VM, a container, or on bare-metal
* Multiple container runtimes (CRI-O, containerd, docker)
* Direct API endpoint for blazing fast [image load and build]({{< ref "/docs/handbook/pushing.md" >}})
* Advanced features such as [LoadBalancer]({{< ref "/docs/handbook/accessing.md#loadbalancer-access" >}}), filesystem mounts, FeatureGates, and [network policy]({{< ref "docs/handbook/network_policy.md" >}})
* [Addons]({{< ref "/docs/handbook/deploying.md#addons" >}}) for easily installed Kubernetes applications
* Supports common [CI environments](https://github.com/minikube-ci/examples)


## Survey

We have a [fast 5-question survey](https://forms.gle/Gg3hG5ZySw8c1C24A) to learn how & why you are using minikube, and what improvements we should make. We would love to hear from you! 🙏

==> minikube-1.38.1.tar.gz: minikube-1.38.1/site/content/en/docs/_index.md <==
---
title: "Welcome!"
linkTitle: "Documentation"
no_list: true
weight: 1
aliases:
  - /docs/overview
---

minikube quickly sets up a local Kubernetes cluster on macOS, Linux, and Windows. We proudly focus on helping application developers and new Kubernetes users.

![Screenshot](/images/screenshot.png)

🎉 Latest Release: v1.38.0 - Jan 28, 2026 ([changelog](https://github.com/kubernetes/minikube/blob/master/CHANGELOG.md))

## Highlights

* Supports the latest Kubernetes release (+6 previous minor versions)
* Supports GPUs for AI development ([nvidia]({{< ref "/docs/tutorials/nvidia.md" >}}), [amd]({{< ref "/docs/tutorials/amd.md" >}}), [apple]({{< ref "/docs/tutorials/ai-playground.md" >}}))
* Cross-platform (Linux, macOS, Windows)
* Deploy as a VM, a container, or on bare-metal or [try in your browser](https://codespaces.new/kubernetes/minikube?quickstart=1).
* Multiple container runtimes (CRI-O, containerd, docker)
* Direct API endpoint for blazing fast [image load and build]({{< ref "/docs/handbook/pushing.md" >}})
* Advanced features such as [LoadBalancer]({{< ref "/docs/handbook/accessing.md#loadbalancer-access" >}}), filesystem mounts, FeatureGates, and [network policy]({{< ref "docs/handbook/network_policy.md" >}})
* [Addons]({{< ref "/docs/handbook/deploying.md#addons" >}}) for easily installed Kubernetes applications
* Supports common [CI environments](https://github.com/minikube-ci/examples)


## Survey

We have a [fast 5-question survey](https://forms.gle/Gg3hG5ZySw8c1C24A) to learn how & why you are using minikube, and what improvements we should make. We would love to hear from you! 🙏
